/* global jQuery, stag_vars */
jQuery( document ).ready( function( $ ) {

	/*------------------------------------------------------------------------------*/
	/* Set cookie for retina displays; refresh if not set
	/*------------------------------------------------------------------------------*/

	( function() {
		'use strict';
		if (
			-1 === document.cookie.indexOf( 'retina' ) &&
			'devicePixelRatio' in window &&
			2 === window.devicePixelRatio
		) {
			document.cookie = 'retina=' + window.devicePixelRatio + ';';
		}
	}() );

	/*------------------------------------------------------------------------------*/
	/* Mobile Navigation Setup
	/*------------------------------------------------------------------------------*/
	var mobileNav = $( '#primary-menu' )
		.clone()
		.attr( 'id', 'mobile-primary-nav' );

	function stag_mobilemenu() {
		'use strict';
		var windowWidth = $( window ).width();
		if ( 992 >= windowWidth ) {
			if ( ! $( '#mobile-nav' ).length ) {
				$(
					'<a id="mobile-nav" href="#mobile-primary-nav"><i class="icon icon-navicon"></i></a>'
				).prependTo( '#navigation' );
				mobileNav
					.insertAfter( '#mobile-nav' )
					.wrap( '<div id="mobile-primary-nav-wrap" />' );
				mobile_responder();
			}
		} else {
			mobileNav.css( 'display', 'none' );
		}
	}
	stag_mobilemenu();

	function mobile_responder() {
		$( '#mobile-nav' ).click( function( e ) {
			if ( $( 'body' ).hasClass( 'ie8' ) ) {
				var mobileMenu = $( '#mobile-primary-nav' );
				if ( 'block' === mobileMenu.css( 'display' ) ) {
					mobileMenu.css({
						display: 'none'
					});
				} else {
					mobileMenu.css({
						display: 'block',
						height: 'auto',
						'z-index': 999,
						position: 'absolute'
					});
				}
			} else {
				$( '#mobile-primary-nav' )
					.stop()
					.slideToggle( 500 );
			}
			e.preventDefault();
		});
	}

	const MOBILE_MENU = debounce( stag_mobilemenu, 200 );
	$( window ).on( 'resize', MOBILE_MENU );

	/* Custom Dropdown for <select> */
	if ( $.isFunction( $.fn.dropdown ) ) {
		$( '.custom-dropdown' ).each( function() {
			$( this ).dropdown({
				stack: false
			});
		});
	}

	/*------------------------------------------------------------------------------*/
	/* Photo Gallery - Isotope
	/*------------------------------------------------------------------------------*/
	var container = $( '#photo-list' );

	if ( $.fn.isotope ) {
		container.imagesLoaded( function() {

			// images have loaded
			container.isotope({
				itemSelector: '.photo',
				layoutMode: 'fitRows'
			});
		});
	}

	// A small hack to make Isotope work on responsive stuff
	$( window ).scroll( function() {
		container.resize();
	});
	container.resize();
	$( window ).resize();

	$( '#filters a' ).click( function() {
		var selector = $( this ).attr( 'data-filter' );
		container.isotope({ filter: selector });

		$( '#filters a' ).removeClass( 'active' );
		$( this ).addClass( 'active' );

		return false;
	});

	/*------------------------------------------------------------------------------*/
	/* Keyboard Navigation
	/*------------------------------------------------------------------------------*/
	$( 'body' ).keydown( function( e ) {
		if ( 39 === e.keyCode ) {
			if ( $( 'a[rel=next]' ).attr( 'href' ) !== undefined ) {
				document.location.href = $( 'a[rel=next]' ).attr( 'href' );
			}
		} else if ( 37 === e.keyCode ) {
			if ( $( 'a[rel=prev]' ).attr( 'href' ) !== undefined ) {
				document.location.href = $( 'a[rel=prev]' ).attr( 'href' );
			}
		}
	});

	/**
	 * RSVP form ajax.
	 */
	$( '#rsvp-form' ).on( 'submit', function( e ) {
		e.preventDefault();

		var form = $( this );

		$.ajax({
			type: 'POST',
			url: stag_vars.ajaxurl,
			data: $( this ).serialize() + '&action=rsvp_widget',
			success: function( response ) {
				var submit = form.find( '#submit_rsvp' ),
					msg;

				if ( true == response.data.result ) {
					msg = submit.data( 'attending' );
				} else if ( false == response.data.result ) {
					msg = submit.data( 'not-attending' );
				}

				form
					.find( '.submit' )
					.prepend( $( '<div class="thanks">' + msg + '</div>' ) );
				form.find( 'input[type="submit"]' ).attr( 'disabled', 'disabled' );
			}
		});
	});

	var $isWidgetized = $( 'body' ).hasClass( 'page-template-widgetized-php' );

	if ( $isWidgetized ) {
		staticContentBackground();
	}

	function staticContentBackground() {
		$( '.page-template-widgetized-php' )
			.find( '.stag_widget_static_content' )
			.each( function() {
				var _this = $( this ),
					bgColor = _this.find( '.hentry' ).data( 'bg-color' ),
					bgImage = _this.find( '.hentry' ).data( 'bg-image' ),
					bgOpacity = parseInt(
						_this.find( '.hentry' ).data( 'bg-opacity' ),
						10
					),
					textColor = _this.find( '.hentry' ).data( 'text-color' ),
					linkColor = _this.find( '.hentry' ).data( 'link-color' );

				_this.prepend( '<div class="static-content-cover" />' );
				_this.find( '.static-content-cover' ).css({
					'background-image': 'url(' + bgImage + ')',
					opacity: bgOpacity / 100,
					'-ms-filter': '"alpha(opacity=' + bgOpacity + ')"'
				});

				_this.css({ 'background-color': bgColor, color: textColor });
				_this.find( 'a' ).css( 'color', linkColor );
				_this
					.find( 'h1, h2, h3, h4, h5, h6, blockquote' )
					.css( 'color', textColor );
			});
	}

	// Returns a function, that, as long as it continues to be invoked, will not
	// be triggered. The function will be called after it stops being called for
	// N milliseconds. If `immediate` is passed, trigger the function on the
	// leading edge, instead of the trailing.
	function debounce( func, wait, immediate ) {
		var timeout;
		return function() {
			var context = this,
			args = arguments;
			var later = function() { // eslint-disable-line
				timeout = null;
				if ( ! immediate ) {
					func.apply( context, args );
				}
			};

			var callNow = immediate && ! timeout;
			clearTimeout( timeout );
			timeout = setTimeout( later, wait );
			if ( callNow ) {
				func.apply( context, args );
			}
		};
	}
});
