<?php
/**
 * Image gallery control.
 *
 * @package Geeklove
 * @since 3.0.0
 */

add_action( 'customize_register', 'geeklove_image_gallery_control' );

function geeklove_image_gallery_control( $wp_customize ) {

	class WP_Customize_Image_Gallery_Control extends WP_Customize_Control {

		public $type = 'multi-image';

		public function __construct( $manager, $id, $args = array() ) {
			parent::__construct( $manager, $id, $args );
		}

		public function enqueue() {
			wp_enqueue_style( 'multi-image-custom-control', get_template_directory_uri() . '/assets/css/customize-image-gallery-control.css', STAG_THEME_VERSION );
		}

		public function render_content() {
			// Get the set values if any.
			$image_srcs = explode( ',', $this->value() );

			if ( ! is_array( $image_srcs ) ) {
				$image_srcs = array();
			}

			$this->the_title();
			$this->the_buttons();
			$this->the_uploaded_images( $image_srcs );
		}

		protected function the_title() {
			?>
			<label>
			<span class="customize-control-title">
				<?php echo esc_html( $this->label ); ?>
			</span>
			</label>
			<?php
		}

		protected function getImages() {
			$options = $this->value();

			if ( ! isset( $options['image_sources'] ) ) {
				return '';
			}

			return $options['image_sources'];
		}

		public function the_buttons() {
			?>
			<div>
			<input type="hidden" value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); ?> class="multi-images-control-input"/>
			<a href="#" class="button-secondary multi-images-upload">
				<?php esc_html_e( 'Select', 'geeklove' ) ?>
			</a>
			<a href="#" class="button-secondary multi-images-remove">
				<?php esc_html_e( 'Remove all images', 'geeklove' ) ?>
			</a>
			</div>
			<?php
		}

		public function the_uploaded_images( $srcs = array() ) {
			?>
			<div class="customize-control-content">
				<ul class="thumbnails">
				<?php if ( is_array( $srcs ) ) : ?>
					<?php foreach ( $srcs as $src ) : ?>
						<?php if ( '' !== $src ) : ?>
							<li class="thumbnail" style="background-image: url(<?php echo esc_url( $src ); ?>);" data-src="<?php echo esc_url( $src ); ?>" >
							</li>
						<?php endif; ?>
					<?php endforeach; ?>
				<?php endif; ?>
				</ul>
			</div>
			<?php
		}
	}
}
