<?php
/**
 * Customizer settings definitions.
 *
 * @package GeekLove
 * @since 3.0.0
 */

/**
 * Get the array of definitions for Customizer settings and controls.
 *
 * @since 3.0.0.
 *
 * @param  object $wp_customize    The Customizer instance.
 *
 * @return mixed|void
 */
function geeklove_customize_get_definitions( $wp_customize ) {
	$google_fonts = geeklove_all_font_choices();

	$wp_customize->add_panel(
		'geeklove_options_panel', array(
			'title'       => esc_html__( 'Theme Options', 'geeklove' ),
			'description' => esc_html__( 'Configure your theme settings', 'geeklove' ),
			'priority'    => 999,
		)
	);
	$wp_customize->add_panel(
		'geeklove_wedding_options', array(
			'title'    => esc_html__( 'Wedding Options', 'geeklove' ),
			'priority' => 1000,
		)
	);

	$definitions = array(
		'colors'                      => array(
			'title'       => esc_html__( 'Styling Options', 'geeklove' ),
			'description' => 'Configure your theme style & accents',
			'priority'    => '',
			'options'     => array(
				'style_background_color' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Background Color', 'geeklove' ),
					),
				),
				'accent-color'           => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Accent Color', 'geeklove' ),
					),
				),
				'text-color'             => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Text Color', 'geeklove' ),
					),
				),
			),
		),

		'geeklove_fonts'              => array(
			'title'       => esc_html__( 'Fonts', 'geeklove' ),
			'panel'       => 'geeklove_options_panel',
			'description' => sprintf(
				/* translators: Link to Google Fonts website */
				esc_html__( 'The list of Google fonts is long! You can %s before making your choices.', 'geeklove' ),
				sprintf(
					'<a href="%1$s" class="external-link" target="_blank">%2$s</a>',
					esc_url( 'https://fonts.google.com' ),
					esc_html__( 'preview', 'geeklove' )
				)
			),
			'options'     => array(
				'font-body'          => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Body', 'geeklove' ),
					),
				),
				'font-headers'       => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Headers', 'geeklove' ),
					),
				),
				'google-font-subset' => array(
					'setting' => array(),
					'control' => array(
						'type'        => 'select',
						'choices'     => geeklove_get_google_font_subsets(),
						'label'       => esc_html__( 'Google Font Subset', 'geeklove' ),
						'description' => sprintf(
							/* translators: Link to Google fonts website */
							esc_html__( 'Not all fonts provide each of these subsets. Please visit the %s to see which subsets are available for each font.', 'geeklove' ),
							sprintf(
								'<a href="%1$s" target="_blank">%2$s</a>',
								esc_url( 'https://fonts.google.com' ),
								esc_html__( 'Google Fonts website', 'geeklove' )
							)
						),
					),
				),
			),
		),
		'blog_settings'               => array(
			'title'   => esc_html__( 'Blog Settings', 'geeklove' ),
			'panel'   => 'geeklove_options_panel',
			'options' => array(
				'geeklove_blog_cover_image'     => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'         => esc_html__( 'Blog Cover', 'geeklove' ),
						'description'   => esc_html__( 'Choose a cover image for blog.', 'geeklove' ),
						'control_class' => 'WP_CUSTOMIZE_IMAGE_CONTROL',
					),
				),
				'geeklove_blog_title'           => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Blog Title', 'geeklove' ),
						'description' => esc_html__( 'Choose the title for blog page', 'geeklove' ),
					),
				),
				'geeklove_blog_subtitle'        => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Blog Subtitle', 'geeklove' ),
						'description' => esc_html__( 'Choose the subtitle for blog page', 'geeklove' ),
					),
				),
				'geeklove_post_excerpt_length'  => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Post Excerpt Length', 'geeklove' ),
						'description' => esc_html__( 'Enter the length of post excerpt for blog page.', 'geeklove' ),
						'type'        => 'number',
					),
				),
				'geeklove_post_excerpt_text'    => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Post Excerpt Text', 'geeklove' ),
						'description' => esc_html__( 'Enter the text for post excerpt read more on blog page.', 'geeklove' ),
						'type'        => 'text',
					),
				),
				'geeklove_disable_seo_settings' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Disable SEO Settings', 'geeklove' ),
						'description' => esc_html__( 'Enable/Disable SEO Settings on single posts and pages.', 'geeklove' ),
						'type'        => 'checkbox',
					),
				),
			),
		),
		'general_settings'            => array(
			'title'   => esc_html__( 'General Settings', 'geeklove' ),
			'panel'   => 'geeklove_options_panel',
			'options' => array(
				'geeklove_text_logo'     => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => esc_html__( 'Plain Text Logo', 'geeklove' ),
						'description' => esc_html( 'Check this box to enable a plain text logo rather than an image logo. Will use your site title.', 'geeklove' ),
					),
				),
				'geeklove_custom_logo'   => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'         => esc_html__( 'Custom Logo Upload', 'geeklove' ),
						'description'   => esc_html__( 'Upload a logo for your theme.', 'geeklove' ),
						'control_class' => 'WP_CUSTOMIZE_IMAGE_CONTROL',
					),
				),
				'geeklove_contact_email' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Contact Form Email Address', 'geeklove' ),
						'description' => esc_html__( 'Enter the email address where you\'d like to receive emails from the contact form, or leave blank to use admin email.', 'geeklove' ),
						'type'        => 'text',
					),
				),
				'geeklove_tracking_code' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Tracking Code', 'geeklove' ),
						'description' => esc_html__( 'Paste your Google Analytics (or other) tracking code here. It will be inserted before the closing body tag of your theme.', 'geeklove' ),
						'type'        => 'textarea',
					),
				),
				'geeklove_site_footer'   => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Footer Text', 'geeklove' ),
						'description' => esc_html__( 'Enter the site footer text.', 'geeklove' ),
						'type'        => 'textarea',
					),
				),
				'geeklove_theme_credit'  => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => esc_html__( 'Hide Theme Credit', 'geeklove' ),
						'type'  => 'checkbox',
					),
				),
			),
		),
		'wedding_bride_settings'      => array(
			'title'       => esc_html__( 'Bride Options', 'geeklove' ),
			'panel'       => 'geeklove_wedding_options',
			'description' => esc_html__( 'Set/Edit Bride Options', 'geeklove' ),
			'options'     => array(
				'geeklove_wedding_bride_first_name' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => __( 'Bride First Name', 'geeklove' ),
						'type'  => 'text',
					),
				),
				'geeklove_wedding_bride_last_name'  => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => __( 'Bride Last Name', 'geeklove' ),
						'type'  => 'text',
					),
				),
				'geeklove_wedding_bride_avatar'     => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'control_class' => 'WP_CUSTOMIZE_IMAGE_CONTROL',
						'label'         => __( 'Bride Avatar', 'geeklove' ),
						'description'   => __( 'Upload the avatar of Bride. Ideal size 115px x 115px or 230px x 230px for retina displays', 'geeklove' ),
					),
				),
				'geeklove_wedding_bride_bio'        => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => __( 'Bride Short Bio', 'geeklove' ),
						'type'  => 'textarea',
					),

				),
			),
		),

		'wedding_bridegroom_settings' => array(
			'title'       => esc_html__( 'Bridegroom Options', 'geeklove' ),
			'panel'       => 'geeklove_wedding_options',
			'description' => esc_html__( 'Set/Edit Bridegroom Options', 'geeklove' ),
			'options'     => array(
				'geeklove_wedding_bridegroom_first_name' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => __( 'Bridegroom First Name', 'geeklove' ),
						'type'  => 'text',
					),
				),
				'geeklove_wedding_bridegroom_last_name'  => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => __( 'Bridegroom Last Name', 'geeklove' ),
						'type'  => 'text',
					),
				),
				'geeklove_wedding_bridegroom_avatar'     => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'control_class' => 'WP_CUSTOMIZE_IMAGE_CONTROL',
						'label'         => __( 'Bridegroom Avatar', 'geeklove' ),
						'description'   => __( 'Upload the avatar of Bridegroom. Ideal size 115px x 115px or 230px x 230px for retina displays', 'geeklove' ),
					),
				),
				'geeklove_wedding_bridegroom_bio'        => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label' => __( 'Bridegroom Short Bio', 'geeklove' ),
						'type'  => 'textarea',
					),
				),
			),
		),
		'wedding_settings'            => array(
			'title'       => esc_html__( 'Wedding Settings', 'geeklove' ),
			'panel'       => 'geeklove_wedding_options',
			'description' => esc_html__( 'Set/Edit Wedding Settings.', 'geeklove' ),
			'options'     => array(
				'geeklove_wedding_date'               => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Wedding Date', 'geeklove' ),
						'description' => esc_html__( 'Select the wedding date in dd-mm-yyyy format.', 'geeklove' ),
						'type'        => 'text',
					),
				),
				'geeklove_wedding_time'               => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Wedding Time', 'geeklove' ),
						'description' => esc_html__( 'Select the wedding time in H:i:s format. For example: 20:12:55; hours, minutes, and seconds respectively.', 'geeklove' ),
						'type'        => 'text',
					),
				),
				'geeklove_guestbook_count'            => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Number of Guestbook messages per page', 'geeklove' ),
						'description' => esc_html__( 'Specify the number of guestbook messages per page', 'geeklove' ),
						'type'        => 'number',
					),
				),
				'geeklove_wedding_slideshow'          => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Image_Gallery_Control',
						'label'         => __( 'Slideshow Images', 'geeklove' ),
						'description'   => __( 'Upload slideshow images for the Intro Section slideshow', 'geeklove' ),
					),
				),
				'geeklove_wedding_slideshow_duration' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => __( 'Slideshow Duration', 'geeklove' ),
						'description' => __( 'Enter the duration between slideshows. 1000 is equal to 1 second.', 'geeklove' ),
						'type'        => 'number',
					),
				),
				'geeklove_wedding_fade_duration'      => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => __( 'Fade Duration', 'geeklove' ),
						'description' => __( 'Enter the duration between slideshows fade animation. 1000 is equal to 1 second.', 'geeklove' ),
						'type'        => 'number',
					),
				),

			),
		),

	);

	/**
	 * Filter the control definitions for the Customizer.
	 *
	 * '[section_id]' => array(
	 *     'title' => esc_html__( '[Section Title]', 'geeklove' ),
	 *     'description' => esc_html__( '[Section description]', 'geeklove' ),
	 *     'options' => array(
	 *         '[setting-id]' => array(
	 *             'setting' => array(
	 *                 [setting-parameter] => [value]
	 *             ),
	 *            'control' => array(
	 *                 [control-parameter] => [value]
	 *             ),
	 *         ),
	 *    ),
	 * ),
	 *
	 * @since 1.0.0.
	 *
	 * @param array    $definitions    The array containing all of the Customizer definitions.
	 */
	$definitions = apply_filters( 'geeklove_customizer_definitions', $definitions );

	return $definitions;
}
