<?php
/**
 * Get a sanitized value for a Theme Mod setting.
 *
 * @param var $setting_id Setting ID.
 *
 * @return mixed
 */
function geeklove_get_thememod_value( $setting_id ) {
	global $geeklove_settings;

	return $geeklove_settings->get_value( $setting_id );
}

/**
 * Migrated from Previous Theme Settings
 * StagFramework
 */
function stag_google_font_url() {

	$body_font    = geeklove_get_thememod_value( 'font-body' );
	$heading_font = geeklove_get_thememod_value( 'font-headers' );

	if ( $body_font === '' && $heading_font === '' ) {
		return;
	}

	$fonts_url     = '';
	$font_families = array();

	$font_families[] = $body_font;
	$font_families[] = $heading_font;

	$query_args = array(
		'family' => urlencode( implode( '|', array_filter( $font_families ) ) ),
		'subset' => urlencode( geeklove_get_thememod_value( 'google-font-subset' ) ),
	);
	$fonts_url  = add_query_arg( $query_args, '//fonts.googleapis.com/css' );

	return esc_url( $fonts_url );
}

if ( ! function_exists( 'stag_remove_trailing_char' ) ) {
	/**
	 * Check if there is any space
	 */
	function stag_remove_trailing_char( $string, $char = ' ' ) {
		$offset        = strlen( $string ) - 1;
		$trailing_char = strpos( $string, $char, $offset );
		if ( $trailing_char ) {
			$string = substr( $string, 0, -1 );
		}
		return $string;
	}
}

function stag_get_font_face( $option ) {
	$stack = null;
	if ( $option != '' ) {
		$option = explode( ':', $option );
		$name   = stag_remove_trailing_char( $option[0] );
		$stack  = $name;
	} else {
		$stack = '';
	}
	return $stack;
}

function stag_user_styles_push( $content ) {
	$body_font        = stag_get_font_face( geeklove_get_thememod_value( 'font-body' ) );
	$heading_font     = stag_get_font_face( geeklove_get_thememod_value( 'font-headers' ) );
	$background_color = geeklove_get_thememod_value( 'style_background_color' );
	$accent           = geeklove_get_thememod_value( 'accent-color' );

	$output = '';

	if ( $background_color != '' ) {
		$output .= "body, .blog-title-inner-wrap{ background-color: {$background_color}; }\n";
		$output .= "hr.section-divider:after, #event:after, .hentry:after, .footer-outer:before, #event:before, #comment-wrap:after, #comment-wrap:before, #tweets:before,#tweets:after,#guestbook-form:after,#guestbook-form:before { background-color: {$background_color}; }\n";
	}

	if ( $body_font != '' ) {
		$output .= "body, button, input[type='text'], .button, input[type=submit], #reply-title small,input[type=email],input[type=url],input[type=number]{ font-family: '{$body_font}'; }\n";
	}

	if ( $heading_font != '' ) :
		$output .= "h1, h2, h3, h4, h5, h6, #countdown .digit, .countdown-amount, .intro-text, blockquote, .thanks,.error-message, .stag-alert, .heading, .gform_description{ font-family: '{$heading_font}'; }";
	endif;

	$output .= ".entry-content li:before, .section-divider:after, .gform_title { color: {$accent}; }";

	$content .= $output . "\n";
	return $content;
}
add_action( 'stag_custom_styles', 'stag_user_styles_push', 10 );


if ( ! function_exists( 'wp_body_open' ) ) {
	/**
	 * Backwards compatibility for wp_body_open.
	 *
	 * @return void.
	 */
	function wp_body_open() {
			do_action( 'wp_body_open' );
	}
}

